Native support of HID input from linux kernel — Kivy v1.0.1-dev documentation

# Native support of HID input from linux kernel

Support start from 2.6.32-ubuntu, or 2.6.34.

To configure HIDInput, put in your configuration

    [input]
    # devicename = hidinput,/dev/input/eventXX
    # example with Stantum MTP4.3" screen
    stantum = hidinput,/dev/input/event2

Note

You must have read access to the input event.

You have the possibility to use custom range for some X, Y and pressure value. On some drivers, the range reported is invalid. To fix that, you can add one of theses options on the argument line :

- invert_x : 1 to invert X axis
- invert_y : 1 to invert Y axis
- min_position_x : X minimum
- max_position_x : X maximum
- min_position_y : Y minimum
- max_position_y : Y maximum
- min_pressure : pressure minimum
- max_pressure : pressure maximum

For example, on Asus T101M, the touchscreen report a range from 0-4095 for X and Y value, but real value are in a range from 0-32768. You can put it on configuration

    [input]
    t101m = hidinput,/dev/input/event7,max_position_x=32768,max_position_y=32768